RdbFileError

Enum RdbFileError 

pub enum RdbFileError {
    InvalidOperation(String),
    Io(Error),
    ZoneUnrecoverable {
        zone: &'static str,
        path: PathBuf,
    },
}

Variants



InvalidOperation(String)



Io(Error)



ZoneUnrecoverable

A named zone of the .rdb cannot be trusted, so the store does not open. ADR 0074 2 requires the zone be named and 4 requires the operator be pointed at red salvage rather than left with a panic.

Fields

zone: &'static str
path: PathBuf