PhysicalFileHeader

Struct PhysicalFileHeader 

pub struct PhysicalFileHeader {
Show 28 fields pub format_version: u32, pub sequence: u64, pub manifest_oldest_root: u64, pub manifest_root: u64, pub free_set_root: u64, pub manifest_page: u32, pub manifest_checksum: u64, pub collection_roots_page: u32, pub collection_roots_checksum: u64, pub collection_root_count: u32, pub snapshot_count: u32, pub index_count: u32, pub catalog_collection_count: u32, pub catalog_total_entities: u64, pub export_count: u32, pub graph_projection_count: u32, pub analytics_job_count: u32, pub manifest_event_count: u32, pub registry_page: u32, pub registry_checksum: u64, pub recovery_page: u32, pub recovery_checksum: u64, pub catalog_page: u32, pub catalog_checksum: u64, pub metadata_state_page: u32, pub metadata_state_checksum: u64, pub vector_artifact_page: u32, pub vector_artifact_checksum: u64,
}
Minimal physical state mirrored into page 0 for paged databases.

The pager owns when this is read and written, but the field layout is a durable file compatibility contract.

Fields

format_version: u32sequence: u64manifest_oldest_root: u64manifest_root: u64free_set_root: u64manifest_page: u32manifest_checksum: u64collection_roots_page: u32collection_roots_checksum: u64collection_root_count: u32snapshot_count: u32index_count: u32catalog_collection_count: u32catalog_total_entities: u64export_count: u32graph_projection_count: u32analytics_job_count: u32manifest_event_count: u32registry_page: u32registry_checksum: u64recovery_page: u32recovery_checksum: u64catalog_page: u32catalog_checksum: u64metadata_state_page: u32metadata_state_checksum: u64vector_artifact_page: u32vector_artifact_checksum: u64